Caption constructor
const
Caption({})
Creates a new Caption object.
This is not recommended for direct use unless you are writing a parser for a new closed captioning file type.
Implementation
const Caption({required this.number, required this.start, required this.end, required this.text});